@@ -3,7 +3,8 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2013, 2014  Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -46,7 +47,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     // -1 = bottom border of the object
     object_data.outer_height = object_data.height-1;
     object_data.height -= this.controls ? 36 : 24;
-  
+
     var id = object_data.linterna_magica_id;
     this.log("LinternaMagica.create_video_object:\n"+
 	     "Creating video object with linterna_magica_id "+id,2);
@@ -70,6 +71,8 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	}
     }
 
+    var toggle_plugin = this.create_toggle_plugin_link(id);
+
     var container = document.createElement("div");
     var object_tag_wrapper = document.createElement("div");
     var object_tag = document.createElement("object");
@@ -165,8 +168,9 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 
     // Firefox Mixed Content blocker
     // https://savannah.nongnu.org/bugs/?39726
-    if(/https:/i.test(window.location.protocol) &&
-       /http:/i.test(object_data.link))
+    if(this.mixed_content ||
+       (/https:/i.test(window.location.protocol) &&
+	/http:/i.test(object_data.link)))
     {
 	var message_mixed = document.createElement("p");
 	message_mixed.textContent =
@@ -232,7 +236,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	var message_enc_sig = document.createElement("p");
 	message_enc_sig.textContent =
 	    this._("It seems that the signatures for this ")+
-	    thhis._("video are encrypted or missing.");
+	    this._("video are encrypted or missing.");
 
 	message_wrapper.appendChild(message_enc_sig);
 
@@ -329,13 +333,42 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     object_tag.setAttribute("data", object_data.link);
     container.appendChild(controls);
 
-    var site_player =  this.get_flash_video_object(id);
+    var site_player =  object_data.site_player;
+
+    if (!site_player)
+    {
+	site_player = this.get_flash_video_object(id);
+    }
 
     if (!site_player)
     {
 	site_player = site_html5_player;
     }
 
+    // Install flash warning in YT
+    var yt_flash_warning = null;
+
+    if (/youtube/i.test(window.location.host) ||
+	/youtube/i.test(window.location.hostname))
+    {
+	yt_flash_warning = document.querySelector(".ytp-error");
+    }
+
+    var dm_media_warning = null;
+
+    if (/dailymotion/i.test(window.location.host) ||
+	/dailymotion/i.test(window.location.hostname))
+    {
+	// Detect if mp4 is supported. If not Dailymotion should
+	// display a warning. The warning is inside an iframe, so it
+	// is not accessible. We want to replace the site player when
+	// it is not able to start. This is kind of heuristic!
+	var v = document.createElement("video");
+	var mp4_support =
+	    v.canPlayType('video/mp4; codecs="avc1.42E01E, mp4a.40.2"');
+	dm_media_warning = mp4_support ? false : true;
+    }
+
     // Remove/hide the object if it is in DOM
     if (site_player &&
 	// The object is still in DOM some scripts remove it
@@ -346,23 +379,53 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	    object_data.use_sibling = site_player.nextSibling;
 	}
 
-	site_player.parentNode.removeChild(site_player);
+	if (this.priority || yt_flash_warning || dm_media_warning ||
+	    this.is_swf_object(site_player))
+	{
+	    if(this.is_swf_object(site_player) || yt_flash_warning ||
+	       dm_media_warning)
+	    {
+		// Ensure it is hidden, not playing and not loadable
+		// if removing from DOM does not work.
+		site_player = this.hide_flash_video_object(site_player);
+		site_player.parentNode.removeChild(site_player);
+	    }
+	    else
+	    {
+		this.pause_site_html5_player(site_player);
+		site_player.style.setProperty("display","none", "important");
+		site_player.parentNode.removeChild(site_player);
+	    }
+	}
     }
 
     if (object_data.use_sibling)
     {
 	object_data.parent.insertBefore(
-	    container,
-	    object_data.use_sibling);
+           container,
+           object_data.use_sibling);
     }
-    else
+    else if (object_data.parent)
     {
-	if (object_data.parent)
-	{
-	    object_data.parent.appendChild(container);
-	}
+	object_data.parent.appendChild(container);
     }
 
+
+    if (!this.priority && !this.is_swf_object(site_player) &&
+	!yt_flash_warning && !dm_media_warning)
+    {
+	// Increase the site player space to fit the LM toggle button
+	object_data.parent.
+	    style.setProperty("height",
+			      object_data.outer_height+27+"px",
+			      "important");
+
+	object_data.parent.appendChild(toggle_plugin);
+
+	this.hide_lm_interface(object_data.linterna_magica_id);
+    }
+
+
     // Objects extracted from script usually does not have cloned object
     // For example youtube
     if (site_player)
